'-----------------------------------------------------------
'Quellprogramm: JULIA4.BAS
'-----------------------------------------------------------
'Das Programm berechnet die Julia-Menge fuer die
'Iteration z(n+1) = z(n)^2 + c nach dem
'Level-Set-Algorithmus. Mit Umkehriteration wird ein
'Punkt der Julia-Menge angenaehert, der anschliessend
'iteriert wird.
'-----------------------------------------------------------
'Eingabewerte:
a = 0                  'Parameter c = (a, b)
b = .5
n0 = 65                'Julia-Mengen-Punkt (n0 > 50)
'-----------------------------------------------------------

SCREEN 12              'VGA, 640 x 480 Pixel, 16 Farben
px = 420: py = 420     'Bildschirmbereich

'z-Ebene                            'mathematischer Bereich
xmin = -2: xmax = 2                 'Realteil
ymin = -2: ymax = 2                 'Imaginaerteil

xschritt = (xmax - xmin) / px       'Schrittweite
yschritt = (ymax - ymin) / py

'Fluchtschranke
r = 2 + SQR(a ^ 2 + b ^ 2)
r2 = r ^ 2

CLS

'Berechnung der ausgefuellten Julia-Menge nach dem
'Level-Set-Algorithmus:
x = 0: y = 0
FOR sx = 0 TO px                    'Bildschirmspalten
   x = xmin + sx * xschritt
   FOR zy = 0 TO py                 'Bildschirmzeilen
      y = ymax - zy * yschritt
      x1 = x: y1 = y
      FOR n = 1 TO 100                 'Iteration
         xx = x1 * x1 - y1 * y1 + a       'Hilfsgroesse
         y1 = 2 * x1 * y1 + b             'Imaginaerteil
         x1 = xx                          'Realteil
         IF x1 * x1 + y1 * y1 > r2 THEN EXIT FOR
      NEXT n
      'Punktausgabe
      IF x1 * x1 + y1 * y1 <= r2 THEN PSET (sx, zy), 9
   NEXT zy
NEXT sx

'Berechnung eines Punktes in der Julia-Menge
'durch Umkehriteration
x = .01: y = 0
FOR i = 1 TO n0
   p = x - a: q = y - b
   IF q = 0 THEN
     IF p <= 0 THEN
       u = 0: v = SQR(-p)
     ELSE
       u = SQR(p): v = 0
     END IF
   ELSE
      u = SQR((p + SQR(p ^ 2 + q ^ 2)) / 2)
      IF u = 0 THEN v = SQR(-p) ELSE v = q / 2 / u
   END IF
   x = u: y = v
   'zufaellige Auswahl der beiden Wurzeln
   IF RND > .5 THEN x = -x: y = -y
NEXT i
                       
sx = (x - xmin) / xschritt
zy = (ymax - y) / yschritt
'Punktausgabe
CIRCLE (sx, zy), 3, 12

'Iteration des Julia-Mengen-Punktes
x1 = x: y1 = y
FOR n = 1 TO 20                  'Iteration
  xx = x1 * x1 - y1 * y1 + a     'Hilfsgroesse
  y1 = 2 * x1 * y1 + b           'Imaginaerteil
  x1 = xx                        'Realteil
  sx = (x1 - xmin) / xschritt
  zy = (ymax - y1) / yschritt
  'Linieausgabe
  LINE -(sx, zy)
NEXT n

LOCATE 28
PRINT "Berechnungsparameter: a = "; a; ";  b = "; b; ""

END



