'---------------------------------------------------
'Quellprogramm: KORBIT1.BAS
'---------------------------------------------------
'Berechnung und grafische Darstellung des Orbits,
'der Fixpunkte der ersten Iterierten sowie
'des Divergenzkreises der komplexen Iteration
'z(n+1) = z(n)^2 + c
'---------------------------------------------------
'Eingabewerte:
a = -.5: b = .5       'Parameter c = (a, b)
x = .5: y = -.5       'Startwert z0 = (x0, y0)
nmax = 30             'Anzahl der Iterationen nmax
'---------------------------------------------------

SCREEN 12
px = 420                          'Bildschirmbereich
py = 420

xmin = -2: xmax = 2               'mathematischer Bereich
ymin = -2: ymax = 2
xschritt = (xmax - xmin) / px     'Schrittweite
yschritt = (ymax - ymin) / py


'Achsenkreuz
LINE (0, ymax / yschritt)-(px, ymax / yschritt)
LINE (-xmin / xschritt, 0)-(-xmin / xschritt, py)

'Fluchtschranke
r = (1 + SQR(1 + 4 * SQR(a ^ 2 + b ^ 2))) / 2
r2 = r ^ 2

'Divergenzskreis
CIRCLE (-xmin / xschritt, ymax / yschritt), r / xschritt, 12

'Einheitskreis
CIRCLE (-xmin / xschritt, ymax / yschritt), 1 / xschritt

'Iteration
sx = (x - xmin) / xschritt     'Startpunkt
zy = (ymax - y) / yschritt
PSET (sx, zy), 12
CIRCLE (sx, zy), 3, 12

FOR i = 1 TO nmax              'Iterationsschleife
   xx = x ^ 2 - y ^ 2 + a
   y = 2 * x * y + b
   x = xx
   IF x ^ 2 + y ^ 2 > r2 THEN EXIT FOR
   sx = (x - xmin) / xschritt
   zy = (ymax - y) / yschritt
   LINE -(sx, zy), 12          'Punktausgabe
   'PSET (sx, zy), 12
NEXT i

'Fixpunkte der 1. Iterierten
p = 1 - 4 * a: q = -4 * b
IF q = 0 THEN
   IF p <= 0 THEN
      u = 0: v = SQR(-p)
   ELSE
      u = SQR(p): v = 0
   END IF
ELSE
   u = SQR((p + SQR(p ^ 2 + q ^ 2)) / 2)
   IF u = 0 THEN v = SQR(-p) ELSE v = q / 2 / u
END IF
x1 = (1 + u) / 2: y1 = v / 2
x2 = (1 - u) / 2: y2 = -v / 2
sx1 = (x1 - xmin) / xschritt: zy1 = (ymax - y1) / yschritt
sx2 = (x2 - xmin) / xschritt: zy2 = (ymax - y2) / yschritt
CIRCLE (sx1, zy1), 3: CIRCLE (sx2, zy2), 3

PRINT "c-Parameter:"
PRINT "("; a; ";"; b; ")"

END


